This is the mail archive of the gdb-patches@sourceware.org mailing list for the GDB project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[ob] rename local variable in break_command_really.


I was doing some local debug changes to break_command_really, that
were introducing a usage of the ALL_BREAKPOINTS macro, and
mysteriously, the result was failing to compile.  Turns out this
function declares a variable named breakpoint_chain, which is the
same name of the global ALL_BREAKPOINTS references...

I've checked this in to hopefully avoid such headaches to
someone else (maybe me!) in the future.

-- 
Pedro Alves

2009-06-11  Pedro Alves  <pedro@codesourcery.com>

	* breakpoint.c (break_command_really): Rename local variable
	breakpoint_chain to bkpt_chain.

---
 gdb/breakpoint.c |   19 +++++++++----------
 1 file changed, 9 insertions(+), 10 deletions(-)

Index: src/gdb/breakpoint.c
===================================================================
--- src.orig/gdb/breakpoint.c	2009-06-11 19:45:08.000000000 +0100
+++ src/gdb/breakpoint.c	2009-06-11 19:47:13.000000000 +0100
@@ -5688,7 +5688,7 @@ break_command_really (char *arg, char *c
   char *addr_start = arg;
   char **addr_string;
   struct cleanup *old_chain;
-  struct cleanup *breakpoint_chain = NULL;
+  struct cleanup *bkpt_chain = NULL;
   struct captured_parse_breakpoint_args parse_args;
   int i;
   int pending = 0;
@@ -5766,12 +5766,11 @@ break_command_really (char *arg, char *c
   /* ----------------------------- SNIP -----------------------------
      Anything added to the cleanup chain beyond this point is assumed
      to be part of a breakpoint.  If the breakpoint create succeeds
-     then the memory is not reclaimed. */
-  breakpoint_chain = make_cleanup (null_cleanup, 0);
+     then the memory is not reclaimed.  */
+  bkpt_chain = make_cleanup (null_cleanup, 0);
 
   /* Mark the contents of the addr_string for cleanup.  These go on
-     the breakpoint_chain and only occure if the breakpoint create
-     fails. */
+     the bkpt_chain and only occur if the breakpoint create fails.  */
   for (i = 0; i < sals.nelts; i++)
     {
       if (addr_string[i] != NULL)
@@ -5843,13 +5842,13 @@ break_command_really (char *arg, char *c
   if (sals.nelts > 1)
     warning (_("Multiple breakpoints were set.\n"
 	       "Use the \"delete\" command to delete unwanted breakpoints."));
-  /* That's it. Discard the cleanups for data inserted into the
-     breakpoint. */
-  discard_cleanups (breakpoint_chain);
-  /* But cleanup everything else. */
+  /* That's it.  Discard the cleanups for data inserted into the
+     breakpoint.  */
+  discard_cleanups (bkpt_chain);
+  /* But cleanup everything else.  */
   do_cleanups (old_chain);
 
   /* error call may happen here - have BREAKPOINT_CHAIN already discarded.  */
   update_global_location_list (1);
 }
 
@@ -5843,13 +5842,13 @@ break_command_really (char *arg, char *c
   do_cleanups (old_chain);
 
-  /* error call may happen here - have BREAKPOINT_CHAIN already discarded.  */
+  /* error call may happen here - have BKPT_CHAIN already discarded.  */
   update_global_location_list (1);
 }


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]